#[derive(GpuiForm)]
{
// Attributes available to this derive:
#[gpui_form]
#[koruma]
}
Derives generated form state, metadata, value holders, and helper APIs.
#[derive(GpuiForm)]
{
// Attributes available to this derive:
#[gpui_form]
#[koruma]
}
Derives generated form state, metadata, value holders, and helper APIs.